package com.ynet.life.loaf.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.action.LifeJDBCAction;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.LoafTools;
import com.ynet.life.loaf.jdbc.LoafQueryFactory;
import com.ynet.life.loaf.jdbc.LoafQueryInterface;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_loaf_action.jar:com/ynet/life/loaf/action/QueryDataListRtFormat.class */
public class QueryDataListRtFormat extends LifeJDBCAction {
    private static final String FIELD_SEPERATOR = "||";
    private String querySql;
    private List inputFields;
    private List outputFields;
    private String sortParam;
    private String dataName;
    private String objSep;
    private String eleSep;
    private int maxNumber;
    private boolean appendFlag = true;
    private static final String ERROR_CODE_POOL = "EBLN0011";

    public String execute(Context context) throws GENEException {
        if (this.dataName == null || "".equals(this.dataName)) {
            throw new TranFailException(ERROR_CODE_POOL, "存储输出结果的数据域集合名称不能为空");
        }
        if (this.querySql == null || "".equals(this.querySql)) {
            throw new TranFailException(ERROR_CODE_POOL, "查询sql语句不能为空");
        }
        if (this.outputFields != null) {
            try {
                if (!"".equals(this.outputFields)) {
                    try {
                        List input = new LinkedList();
                        String finalSQL = LoafTools.parseQuerySql(context, this.querySql, input);
                        LoafQueryInterface query = LoafQueryFactory.getNewQuery("", this.sortParam, finalSQL);
                        query.setMaxNumber(this.maxNumber);
                        PreparedStatement ps = null;
                        ResultSet resultSet = null;
                        try {
                            try {
                                Connection connection = LifeDBAccess.getConnection(getDataSource());
                                PreparedStatement queryStatement = query.getQueryStatement(connection, input);
                                ps = queryStatement;
                                resultSet = queryStatement.executeQuery();
                                String resultstr = fillResultIntoIcoll(resultSet);
                                System.out.print("=========================================================================".concat(String.valueOf(resultstr)));
                                context.put(this.dataName, resultstr);
                                LifeDBAccess.cleanResources(ps, resultSet);
                                LifeDBAccess.releaseConnection(getDataSource(), connection);
                                return "0";
                            } catch (SQLException ex) {
                                throw new TranFailException("EBLN0000", ex);
                            }
                        } catch (Throwable th) {
                            LifeDBAccess.cleanResources(ps, resultSet);
                            throw th;
                        }
                    } catch (GENEException empe) {
                        Trace.logError("LOAF", empe.getMessage(), empe);
                        throw empe;
                    }
                }
            } catch (Throwable th2) {
                LifeDBAccess.releaseConnection(getDataSource(), (Connection) null);
                throw th2;
            }
        }
        throw new TranFailException(ERROR_CODE_POOL, "存储输出结果的数据域名称不能为空");
    }

    private String fillResultIntoIcoll(ResultSet resultSet) throws SQLException, GENEException {
        int dateSize = this.outputFields.size();
        if (dateSize <= 0) {
            return "";
        }
        StringBuilder resultStr = new StringBuilder();
        while (resultSet.next()) {
            for (int i = 1; i < dateSize; i++) {
                String dataFieldValue = resultSet.getString(i);
                resultStr.append(dataFieldValue);
                resultStr.append(this.eleSep);
            }
            resultStr.append(resultSet.getString(dateSize));
            if (!resultSet.isLast()) {
                resultStr.append(this.objSep);
            }
        }
        return resultStr.toString();
    }

    public void setDataName(String dataName) {
        this.dataName = dataName;
    }

    public void setSortParam(String sortParam) {
        this.sortParam = sortParam;
    }

    public void setObjSep(String objSep) {
        this.objSep = objSep;
    }

    public void setEleSep(String eleSep) {
        this.eleSep = eleSep;
    }

    public void setOutputFields(String outputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(outputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.outputFields = result;
    }

    public void setQuerySql(String querySql) {
        this.querySql = querySql;
    }

    public void setMaxNumber(int maxNumber) {
        this.maxNumber = maxNumber;
    }

    public boolean isAppendFlag() {
        return this.appendFlag;
    }

    public void setAppendFlag(boolean appendFlag) {
        this.appendFlag = appendFlag;
    }
}
